Please see [https://docs.mlcommons.org/cm4mlops/scripts/Legacy-CK-support/get-ck-repo-mlops](https://docs.mlcommons.org/cm4mlops/scripts/Legacy-CK-support/get-ck-repo-mlops) for the documentation of this CM script.
